@@ -16,7 +16,7 @@ use vars qw ($VERSION);
 
 my $author = '';
 my $title = '';
-$VERSION="v5.0792";
+$VERSION="v5.0793";
 
 my $version=
   "Almost Free Text $VERSION; Copyright 1996-2002 Todd Coram. All rights reserved.";
@@ -484,7 +484,7 @@ sub handleSections {
     # print section name
     #
     &output($AFT_OUTPUT::elem{$1}."\n", section => $sname, 
-	    text => $full_sname, number => $number);
+	    text => &filter($full_sname), number => $number);
     
     # Save the section for the TOC file.
     #
@@ -510,9 +510,11 @@ sub handleLists {
   #	<tab>[text]
   #	<tab>number.
   #	<tab>number)
+  #     <tab>#)
+  #     <tab>#.
   #
   (!$mode->{inVerbatim} && !$mode->{inQuote} && 
-   (/^(\t{1,})(\*|\[[^\]]+\]|\d+[.\)])/)) && do {
+   (/^(\t{1,})(\*|\[[^\]]+\]|\#[.\)]|\d+[.\)])/)) && do {
      my $rest_of_line = $';
      my $list = '';
      my ($le, $name);
